@@ -28,7 +28,7 @@ class Base(object):
         return self.__context
 
     def __getattr__(self, item):
-        if not self.__dict__.has_key('superclass'):
+        if not 'superclass' in self.__dict__:
             return self.__getattribute__(item)
         return self.superclass.__getattribute__(item)
 
@@ -43,3 +43,9 @@ class Base(object):
             raise ImmutableError(name)
         else:
             super(Base, self).__setattr__(name, value)
+
+    def export_(self, outfile, level, namespace_='', name_='', namespacedef_='', pretty_print=True):
+        # This empty method is necessary in order to avoid exceptions when the
+        # infrastructure tries to invoke it on a collection decorator that is
+        # used as a parameter.
+        pass
